QueueLink Module API Documentation
==================================

.. module:: queuelink

This page covers the QueueLink module interfaces.

Factory Function
----------------

.. autofunction:: link

QueueLink Class
---------------

.. autoclass:: QueueLink
   :members:

Handle-to-Queue Adapter (Reader)
--------------------------------

.. autoclass:: QueueHandleAdapterReader
   :members:
   :inherited-members:

Queue-to-Handle Adapter (Writer)
--------------------------------

.. autoclass:: QueueHandleAdapterWriter
   :members:
   :inherited-members:
